`define MEMORY_SIZE 65536

//Joe 4-12-01, modify cs_b[0:9] to cs_b
module sram(a, cs_b, d, we_b, oe_b);

input [0:31] a;			// address bus (we use only a[16:31])
input cs_b;		        // chip select signal (we use cs_b[0])
inout [0:63] d;			// data bus
input [0:7] we_b;		// write enable signal (totaly 8 signals for each byte)
input oe_b;			// output enable signal (works for all bytes being read)

//  memory array
//
reg [0:7] memory [0:`MEMORY_SIZE-1];

//  memory reading support
//

assign d[ 0: 7] = (cs_b === 0 && oe_b === 0) ? memory[a[16:31] + 0] : 8'bzzzzzzzz;
assign d[ 8:15] = (cs_b === 0 && oe_b === 0) ? memory[a[16:31] + 1] : 8'bzzzzzzzz;
assign d[16:23] = (cs_b === 0 && oe_b === 0) ? memory[a[16:31] + 2] : 8'bzzzzzzzz;
assign d[24:31] = (cs_b === 0 && oe_b === 0) ? memory[a[16:31] + 3] : 8'bzzzzzzzz;
assign d[32:39] = (cs_b === 0 && oe_b === 0) ? memory[a[16:31] + 4] : 8'bzzzzzzzz;
assign d[40:47] = (cs_b === 0 && oe_b === 0) ? memory[a[16:31] + 5] : 8'bzzzzzzzz;
assign d[48:55] = (cs_b === 0 && oe_b === 0) ? memory[a[16:31] + 6] : 8'bzzzzzzzz;
assign d[56:63] = (cs_b === 0 && oe_b === 0) ? memory[a[16:31] + 7] : 8'bzzzzzzzz;


//  memory writing support processes
//

always
begin
   wait(cs_b === 0 && we_b[0] === 0);
   memory[a[16:31]] = d[0:7];
   wait(cs_b !== 0 || we_b[0] !== 0);
end

always
begin
   wait(cs_b === 0 && we_b[1] === 0);
   memory[a[16:31] + 1] = d[8:15];
   wait(cs_b !== 0 || we_b[1] !== 0);
end

always
begin
   wait(cs_b === 0 && we_b[2] === 0);
   memory[a[16:31] + 2] = d[16:23];
   wait(cs_b !== 0 || we_b[2] !== 0);
end

always
begin
   wait(cs_b === 0 && we_b[3] === 0);
   memory[a[16:31] + 3] = d[24:31];
   wait(cs_b !== 0 || we_b[3] !== 0);
end

always
begin
   wait(cs_b === 0 && we_b[4] === 0);
   memory[a[16:31] + 4] = d[32:39];
   wait(cs_b !== 0 || we_b[4] !== 0);
end

always
begin
   wait(cs_b === 0 && we_b[5] === 0);
   memory[a[16:31] + 5] = d[40:47];
   wait(cs_b !== 0 || we_b[5] !== 0);
end

always
begin
   wait(cs_b === 0 && we_b[6] === 0);
   memory[a[16:31] + 6] = d[48:55];
   wait(cs_b !== 0 || we_b[6] !== 0);
end

always
begin
   wait(cs_b === 0 && we_b[7] === 0);
   memory[a[16:31] + 7] = d[56:63];
   wait(cs_b !== 0 || we_b[7] !== 0);
end

//  load data to the memory from a text file
//
task load_data;
    input file_name;
    reg [8*40:1] file_name;
begin
    $readmemh(file_name, memory);
end
endtask

//  print memory content
//
task dump;
integer i;
begin
   for(i = 0; i < `MEMORY_SIZE; i = i + 1)
       $display("%h", memory[i]);
end
endtask


endmodule
